% --- Source file: treat.plink.Rd ---
\name{treat.plink}
\alias{treat.plink}
\title{TREe-based Association Test}
\description{
  The tree-based association test used with PLINK files
}
\usage{
treat.plink(plink.files, formula, data, id.vars, gene.obj, op=NULL) 
}
\arguments{
  \item{plink.files}{A character vector of the .bed, .bim and .fam files in this order.}
  \item{formula}{See \code{\link{treat}}. }
  \item{data}{A data frame containing the response, id variables and covariates. }
  \item{id.vars}{Character vector of length 2 which gives the \code{family id} and \code{subject id}
              in this order. }
  \item{gene.obj}{Vector of gene names or a matrix with at least 3 columns called 
              "Chr", "Start", "Stop" which give the chromosome, starting location and ending location
              for each gene to analyze. This matrix can also have a column called "Gene".}
  \item{op}{A list of options (see details below and the options in \code{\link{treat}}). 
            The default value is NULL.}
}
\value{
  The returned object is a list containing a \code{summary} and 
  a character vector \code{saved.files} of the output files created. 
  Each output file is
  an R object file in directory \code{op$out.dir} with name \code{<gene>.rda} containing the 
  returned object from \code{\link{treat}}.
 }

\details{  
   
  \bold{Options list:} \cr
 Below are the names for the options list \code{op}. All names have default values
         if they are not specified.
\itemize{
  \item{\code{out.dir}}{ The output directory to save an R object file for each gene analyzed.
                         The default is the working directory \code{\link[base]{getwd}} }.
  \item{\code{gene.db}}{ "hg18", "hg19" or a gene database file of a particular format. The format must be 
                         an R object file containing a single matrix or data frame with columns
                         "Chr", "Start", "Stop", and "Gene". This option is only used when \code{gene.obj}
                         is a vector of gene names.
                         The default is "hg18".}
  \item{\code{delta}}{ Integer number of base-pairs to subtract/add to a gene's starting/ending locations.
                       For example, if a gene had starting/ending locations of a and b, then all SNPs with
                       with location \code{[a-delta, a+delta]} will be included in the gene.
                       The default is 20000.}
} % END: itemize


} % END: details

%\references{ }
\author{Han Zhang and Kai Yu }
\seealso{ \code{\link{treat}} }
\examples{

  # Get the data
  bed <- system.file("sampleData", "data.bed", package="TREAT")
  bim <- system.file("sampleData", "data.bim", package="TREAT")
  fam <- system.file("sampleData", "data.fam", package="TREAT")

  # Create a data frame with the id variables, response and covariates
  x <- read.table(fam, header=0, stringsAsFactors=FALSE)
  colnames(x) <- c("FAMILY", "SUBJECT", "FATHER", "MOTHER", "SEX", "Y")

  # Create the gene object
  gene.obj <- rbind(c(8, 12799052, 12895289, "Gene1"), 
                    c(8, 12868315, 12989321, "Gene2"))
  colnames(gene.obj) <- c("Chr", "Start", "Stop", "Gene")

  formula <- as.formula(Y ~ SEX)
  id.vars <- c("FAMILY", "SUBJECT")

  # Specify options. 
  # The example data shown here has small sample size 
  # We modify the options to illustrate more details of the output 
  op <- list(thr.sample = 10, thr.leaf.size = 5)

  tr <- treat.plink(c(bed, bim, fam), formula, x, id.vars, gene.obj, op=op)
  tr

  # the path of the created output files
  tr$saved.files

  # load the output for Gene1, which is an R object named "obj"
  load(tr$saved.files["Gene1"])

  obj$adj.pval
  obj$tree.model.forward

}

\keyword{model} 

