
#include "gene_ctree3.hpp"


class GENE_CTREE{
	
	private:
		int *data;
		int *data2;
		int *covar;
		int nperm;
		int buffer;
		int thr_sample;
		int thr_grp_sample_size;
		int nleaf;
		int thr_leaf_size;
		int seed;
		bool two_way;
		bool backward;
		bool cal_pval;
		char *path_output;
		char *path_output_back;
		
		double adj_pval;
		double try_adj_pval;
		vector<double> unadj_pval;
		vector<double> try_unadj_pval;
		
		double adj_pval_back;
		double try_adj_pval_back;
		vector<double> unadj_pval_back;
		vector<double> try_unadj_pval_back;
		
		double *pval;
		double *pval_back;
		int *model;
		vector<int> vmodel;
		
		vector<int> cut_point;
		
		vector<bitvec > covar64;
		vector<bitvec > indicator64;
		vector<bitvec > not_indicator64;
		vector<bitvec > two_way_indicator64;
		vector<bitvec > two_way_not_indicator64;
		
		vector<vector<int> > covar_idx;
		vector<int> ind_N;
		vector<int> ind2_N;
		
		bitvec all_one;
		bitvec y64;
		bitvec not_y64;
		vector<int> y;
		
		vector<VecScore> global_stat;
		vector<VecScore> global_stat_back;
		
		vector<int> bitloc;
		vector<int> offset;
		bitvec MASK_offset;
		bitvec not_MASK_offset;
		vector<int> getlowbit;
		
		int ncase;
		int nctrl;
		int N;
		int nind;
		int nind2;
		int ngrp;
		int ncp;
		
		vector<int> grp_ncase;
		vector<int> grp_nctrl;
		vector<int> grp_N;
				
		uint64 MASK;
		int LEN_LONG;
		int nblock;
		
		bool debug;
		bool trace;
		bool bin;
		bool rec_model;
		
		
		inline int popcount(uint64 x){ return wordbits[x & 0xFFFF] + wordbits[(x >> 16) & 0xFFFF] + wordbits[(x >> 32) & 0xFFFF] + wordbits[x >> 48]; }
		void format();
		void global_test(vector<NODE*>&, double&);
		bool group_split(NODE&);
		bool group_split2(NODE&);
		bool backward_search(vector<NODE*>&, vector<double>&);
		bool backward_search1(vector<NODE*>&, vector<double>&);
		void destroy_tree(vector<NODE*>&);
		void print_table(const NODE&);
		void grow_tree(vector<double>&, vector<double>&);
		void grow_tree2(vector<double>&, vector<double>&);
		vector<int> bit2int(const bitvec&);
		void swap(bitvec&, int, int);
		void permutation();
		void permute_by_covar();
		void try_calculate_pvalue(const int&);
		void calculate_pvalue();
		void store();
		void store_binary();
		void get_pvalue();

	public:
		
		GENE_CTREE(int *const, int *const, int *const, const bool,
	const bool, const bool, char**, char**, const int, const int, const int, 
	const int, const int, const int, const int, const int, int *const, 
	const int, const int, const bool, const int, const bool, const bool, double*, double*, int*);
		~GENE_CTREE();
		void test_tree();
		

		friend bitvec operator&(const bitvec&, const bitvec&);
		friend ostream& operator<<(ostream&, const vector<double>&);
		
};


GENE_CTREE::~GENE_CTREE(){
	
	delete[] path_output;
	delete[] path_output_back;
	
}


GENE_CTREE::GENE_CTREE(int *const input_data, int *const input_data2, int *const input_covar, const bool input_two_way,
	const bool input_backward, const bool input_cal_pval, char **input_path_output, char **input_path_output_back, 
	const int input_N, const int input_nind, const int input_nind2, const int input_ngrp, const int input_thr_sample, 
	const int input_thr_grp_sample_size, const int input_thr_leaf_size, const int input_nleaf, int *const input_cut_point, 
	const int input_ncp, const int input_nperm, const bool input_trace, const int input_seed, const bool input_debug, 
	const bool input_bin, double *input_pval, double *input_pval_back, int *input_model){
	
	seed = input_seed;
	if(seed < 0){
		srand(time(NULL));
	}else{
		srand(seed);
	}
	
	data = input_data;
	data2 = input_data2;
	two_way = input_two_way;
	backward = input_backward;
	cal_pval = input_cal_pval;
	covar = input_covar;
	ncp = input_ncp;
	cut_point = vector<int> (ncp, 0);
	for(int i = 0; i < ncp; ++i){
		cut_point[i] = input_cut_point[i]-2;
	}
	N = input_N;
	nind = input_nind;
	nind2 = input_nind2;
	ngrp = input_ngrp;
	nperm = input_nperm;
	buffer = min(1000, nperm);
	thr_sample = input_thr_sample;
	thr_grp_sample_size = input_thr_grp_sample_size;
	nleaf = input_nleaf;
	thr_leaf_size = input_thr_leaf_size;
	debug = input_debug;
	trace = input_trace;
	bin = input_bin;
	rec_model = true;
	path_output = new char[2000];
	strcpy(path_output, *input_path_output);
	path_output_back = new char[2000];
	strcpy(path_output_back, *input_path_output_back);
	pval = input_pval;
	pval_back = input_pval_back;
	model = input_model;
	
	MASK = 0x8000000000000000;
	LEN_LONG = 64;
	nblock = (int) ceil(((double) N)/LEN_LONG);
	
	//preparing for massive inquiries
	for(int i = 0; i < 65536; ++i){
		wordbits[i] = bitcount(i);
	}
	
	format();
	
}

void GENE_CTREE::format(){
	
	bitloc.reserve(N);
	offset.reserve(N);
	MASK_offset.reserve(N);
	not_MASK_offset.reserve(N);
	getlowbit.reserve(N);
	for(int k = 0; k < N; ++k){
		bitloc.push_back(k/LEN_LONG); //indicate the block No. where the k-th sample locates
		offset.push_back(k % LEN_LONG); //indicate the offset in a block where the k-th sample locates
		MASK_offset.push_back(MASK >> (k % LEN_LONG)); //make a mask for indicating the offset in a block with length LEN_LONG
		not_MASK_offset.push_back(~(MASK >> (k % LEN_LONG)));
		getlowbit.push_back(LEN_LONG - (k % LEN_LONG) - 1);
	}
	
	y = vector<int> (N, 0);
	all_one = bitvec(nblock, (uint64) 0);//must initialized as 0
	y64 = bitvec(nblock, (uint64) 0);//must initialized as 0
	not_y64 = bitvec(nblock, (uint64) 0);//must initialized as 0
	indicator64 = vector<bitvec > (nind, bitvec(nblock, (uint64) 0));//must initialized as 0
	not_indicator64 = vector<bitvec > (nind, bitvec(nblock, (uint64) 0));//must initialized as 0
	two_way_indicator64 = vector<bitvec > (nind2, bitvec(nblock, (uint64) 0));//must initialized as 0
	two_way_not_indicator64 = vector<bitvec > (nind2, bitvec(nblock, (uint64) 0));//must initialized as 0
	covar64 = vector<bitvec > (ngrp, bitvec(nblock, (uint64) 0));//must initialized as 0
	covar_idx = vector<vector<int> > (ngrp, vector<int> (1, -1));
	ind_N = vector<int> (nind, 0); //must initialized as 0
	ind2_N = vector<int> (nind2, 0);
	
	for(int ii = 0; ii < ngrp; ++ii){
		covar_idx[ii].clear();
	}
	
	int d, g, x;
	ncase = 0;
	nctrl = 0;
	for(int k = 0; k < N; ++k){
		d = data[k];
		if(d != 0 && d != 1){
               error("The outcome must be coded as 0 and 1");
		}
		
		d ? ncase++ : nctrl++;
		
		all_one[bitloc[k]] |= MASK_offset[k];
		
		y[k] = d;
		if(d){
			y64[bitloc[k]] |= MASK_offset[k];
		}else{
			not_y64[bitloc[k]] |= MASK_offset[k];
		}
		
		for(int j = 0; j < nind; ++j){
			g = data[k + (j +1) * N];
			if(g != 0 && g != 1){
				error("The indicator of genotypes must be coded as 0, 1");
			}
			if(g){
				indicator64[j][bitloc[k]] |= MASK_offset[k];
				ind_N[j]++;
			}else{
				not_indicator64[j][bitloc[k]] |= MASK_offset[k];
			}
			
		}
		
		for(int j = 0; j < nind2; ++j){
			g = data2[k + j * N];
			if(g != 0 && g != 1){
				error("The indicator of 2-way genotypes must be coded as 0, 1");
			}
			if(g){
				two_way_indicator64[j][bitloc[k]] |= MASK_offset[k];
				ind2_N[j]++;
			}else{
				two_way_not_indicator64[j][bitloc[k]] |= MASK_offset[k];
			}
			
		}
		
		////////////
		
		x = covar[k];
		if(x < 0 || x >= ngrp){
			error("The indicator of covariate must be coded as 0, 1, ..., ");
		}
		
		covar_idx[x].push_back(k);
		
		covar64[x][bitloc[k]] |= MASK_offset[k];
		
	}
	
	//we adopt a permutation within each group, so grp_** are unchanged
	grp_ncase = vector<int> (ngrp, 0);
	grp_nctrl = vector<int> (ngrp, 0);
	grp_N = vector<int> (ngrp, 0);
	for(int l = 0; l < ngrp; ++l){
		for(int j = 0; j < nblock; ++j){
			grp_ncase[l] += popcount(covar64[l][j] & y64[j]);
			grp_nctrl[l] += popcount(covar64[l][j] & not_y64[j]);
		}
		grp_N[l] = grp_ncase[l] + grp_nctrl[l];
	}
	
}


void GENE_CTREE::global_test(vector<NODE*> &plf, double &gst){
	
	int nlf = plf.size();
	gst = .0;
	
	double **I_null = new double*[nlf-1];
	double **inv_I_null = new double*[nlf-1];
	for(int i = 0; i < nlf-1; ++i){
		I_null[i] = new double[nlf-1];
		inv_I_null[i] = new double[nlf-1];
		for(int j = 0; j < nlf-1; ++j){
			I_null[i][j] = .0;
			inv_I_null[i][j] = .0;
		}
	}
	
	vector<double> score(nlf-1, .0);
	
	for(int k = 0; k < nlf-1; ++k){
		NODE &node_k = (*(plf[k]));
		for(int l = 0; l < ngrp; ++l){
			double r = node_k.grp_N[l] * 1.0 / grp_N[l];
			I_null[k][k] += r * (1.0 - r) * grp_ncase[l] * grp_nctrl[l] / (grp_N[l] - 1.0);
			score[k] += node_k.grp_ncase[l] - grp_ncase[l] * r;
		}
		
		if(k > 0){
			for(int j = 0; j < k; ++j){
				NODE &node_j = (*(plf[j]));
				for(int l = 0; l < ngrp; ++l){
					I_null[k][j] -= node_k.grp_N[l] * 1.0 / grp_N[l] * node_j.grp_N[l] * 1.0 / grp_N[l]  * grp_ncase[l] * grp_nctrl[l] / (grp_N[l] - 1.0);
				}
				I_null[j][k] = I_null[k][j];
				
			}
		}
	}
	
	cov_inv(I_null, nlf-1, inv_I_null);
	
	vector<double> tmpv(nlf-1, .0);
	gst = .0;
	for(int i = 0; i < nlf-1; ++i){
		for(int j = 0; j < nlf-1; ++j){
			tmpv[i] += score[j] * inv_I_null[j][i];
		}
		gst += score[i] * tmpv[i];
	}
	
	for(int i = 0; i < nlf-1; ++i){
		delete [] I_null[i];
		delete [] inv_I_null[i];
	}
	delete I_null;
	delete inv_I_null;
	
}



bool GENE_CTREE::group_split(NODE & node){
	
	if(!node.processed && !node.terminal){
		
		double max_split_stat = -1.0;
		int candidate_split_index = -1;
		
		bool valid_node = false;
		bool valid_min_group_sample = false;
		if(node.min_group_sample_size < thr_grp_sample_size){
			valid_min_group_sample = false;
		}else{
			valid_min_group_sample = true;
		}
		
		if(valid_min_group_sample){
			for(int i = 0; i < nind; ++i){
				bitvec *pind = &(indicator64[i]);
				if(!node.valid_indicator[i]){
					if(debug){
						Rprintf("**************\n");
						Rprintf("node id: %d used indicator. skip the %d -th indicator\n", node.node_id, i);
					}
					continue;
				}
				
				/*
				NODE *np = node.parent;
				bool skip = false;
				while(np){
					if(i == (*np).split_index){
						node.valid_indicator[i] = false;
						skip = true;
						break;
					}else{
						np = (*np).parent;
						skip = false;
					}
				}
				
				if(skip){
					if(debug){
						Rprintf("**************\n");
						Rprintf("node id: %d used indicator. skip the %d -th indicator\n", node.node_id, i);
					}
					continue;
				}
				*/
				
				int sample_size_left = 0;
				int sample_size_right = 0;
				
				vector<int> *pcnt0 = NULL;
				vector<int> *pcnt1 = NULL;
				vector<int> *pcnt2 = NULL;
				bitvec *pcovar = NULL;
				for(int l = 0; l < ngrp; ++l){
					pcnt0 = &(node.cnt[l][0]);
					pcnt1 = &(node.cnt[l][1]);
					pcnt2 = &(node.cnt[l][2]);
					pcovar = &(covar64[l]);
					
					(*pcnt0)[1] = 0;
					(*pcnt1)[1] = 0;
					
					uint64 tmp;
					for(int j = 0; j < nblock; ++j){
						if(!(*pcovar)[j]){
							continue;
						}
						tmp = (*pcovar)[j] & node.sample_index[j] & (*pind)[j];
						//(*pcnt0)[1] += popcount(node.sample_index[j] & (*pcovar)[j] & not_y64[j] & (*pind)[j]);
						//(*pcnt1)[1] += popcount(node.sample_index[j] & (*pcovar)[j] & y64[j] & (*pind)[j]);
						(*pcnt0)[1] += popcount(tmp & not_y64[j]);
						(*pcnt1)[1] += popcount(tmp & y64[j]);
					}
					(*pcnt0)[0] = (*pcnt0)[2] - (*pcnt0)[1];
					(*pcnt1)[0] = (*pcnt1)[2] - (*pcnt1)[1];
					(*pcnt2)[0] = (*pcnt0)[0] + (*pcnt1)[0];
					(*pcnt2)[1] = (*pcnt0)[1] + (*pcnt1)[1];
					
					sample_size_left += (*pcnt2)[0];
					sample_size_right += (*pcnt2)[1];
				}
				pcnt0 = NULL;
				pcnt1 = NULL;
				pcnt2 = NULL;
				pcovar = NULL;
				
				if(sample_size_left < thr_leaf_size || sample_size_right < thr_leaf_size){
					
					if(debug){
						Rprintf("**************\n");
						Rprintf("node id: %d small leaves. skip the %d -th indicator\n", node.node_id, i);
					}
					
					node.valid_indicator[i] = false;
					continue;
				}
				
				if(debug){
					
					Rprintf("**************\n");
					Rprintf("node id: %d %d -th indicator\n", node.node_id, i);
					for(int ll = 0; ll < ngrp; ++ll){
						for(int ii = 0; ii < 3; ++ii){
							for(int jj = 0; jj < 3; ++jj){
								Rprintf("%d\t", node.cnt[ll][ii][jj]);
							}
							Rprintf("\n");
						}
						Rprintf("---------/ %d \\---------\n", ll);
					}
					
				}
				
				double score = .0;
				double var = .0;
				double r = .0;
				for(int l = 0; l < ngrp; ++l){
					r = node.cnt[l][2][1] * 1.0 / node.cnt[l][2][2];
					score += node.cnt[l][1][1] - node.cnt[l][1][2] * r;
					var += r * (1.0 - r) * node.cnt[l][1][2] / (node.cnt[l][2][2] - 1.0) * node.cnt[l][0][2];
				}
				
				double stat2by2 = score * score / var;
				if(debug){
					Rprintf("The 1-df statistics %g \n", stat2by2);
				}
				
				
				valid_node = true;
				
				if(max_split_stat <= stat2by2){
					max_split_stat = stat2by2;
					candidate_split_index = i;
					vector<int> *pcand_cnt0 = NULL;
					vector<int> *pcand_cnt1 = NULL;
					vector<int> *pcnt0 = NULL;
					vector<int> *pcnt1 = NULL;
					for(int l = 0; l < ngrp; ++l){
						pcand_cnt0 = &(node.candidate_split_cnt[l][0]);
						pcand_cnt1 = &(node.candidate_split_cnt[l][1]);
						pcnt0 = &(node.cnt[l][0]);
						pcnt1 = &(node.cnt[l][1]);
						(*pcand_cnt0)[0] = (*pcnt0)[0];
						(*pcand_cnt0)[1] = (*pcnt0)[1];
						(*pcand_cnt1)[0] = (*pcnt1)[0];
						(*pcand_cnt1)[1] = (*pcnt1)[1];
					}
					pcand_cnt0 = NULL;
					pcand_cnt1 = NULL;
					pcnt0 = NULL;
					pcnt1 = NULL;
				}
			}
		}
		
		if(valid_node){
			node.candidate_split_stat = max_split_stat;
			node.candidate_split_index = candidate_split_index;
			node.processed = true;
			node.terminal = false;
			
			return !node.terminal;
		}else{
			node.processed = true;
			node.terminal = true;
			
			return !node.terminal;
		}
	}else{
		return !node.terminal;
	}
	
	
}


bool GENE_CTREE::group_split2(NODE & node){
	
	if(!node.processed && !node.terminal){
		
		double max_split_stat = -1.0;
		int candidate_split_index = -1;
		
		bool valid_node = false;
		bool valid_min_group_sample = false;
		if(node.min_group_sample_size < thr_grp_sample_size){
			valid_min_group_sample = false;
		}else{
			valid_min_group_sample = true;
		}
		
		if(valid_min_group_sample){
			for(int i = 0; i < nind2; ++i){
				bitvec *pind = &(two_way_indicator64[i]);
				
				int sample_size_left = 0;
				int sample_size_right = 0;
				
				vector<int> *pcnt0 = NULL;
				vector<int> *pcnt1 = NULL;
				vector<int> *pcnt2 = NULL;
				bitvec *pcovar = NULL;
				for(int l = 0; l < ngrp; ++l){
					pcnt0 = &(node.cnt[l][0]);
					pcnt1 = &(node.cnt[l][1]);
					pcnt2 = &(node.cnt[l][2]);
					pcovar = &(covar64[l]);
					
					(*pcnt0)[1] = 0;
					(*pcnt1)[1] = 0;
					
					uint64 tmp;
					for(int j = 0; j < nblock; ++j){
						if(!(*pcovar)[j]){
							continue;
						}
						tmp = (*pcovar)[j] & node.sample_index[j] & (*pind)[j];
						//(*pcnt0)[1] += popcount(node.sample_index[j] & (*pcovar)[j] & not_y64[j] & (*pind)[j]);
						//(*pcnt1)[1] += popcount(node.sample_index[j] & (*pcovar)[j] & y64[j] & (*pind)[j]);
						(*pcnt0)[1] += popcount(tmp & not_y64[j]);
						(*pcnt1)[1] += popcount(tmp & y64[j]);
					}
					(*pcnt0)[0] = (*pcnt0)[2] - (*pcnt0)[1];
					(*pcnt1)[0] = (*pcnt1)[2] - (*pcnt1)[1];
					(*pcnt2)[0] = (*pcnt0)[0] + (*pcnt1)[0];
					(*pcnt2)[1] = (*pcnt0)[1] + (*pcnt1)[1];
					
					sample_size_left += (*pcnt2)[0];
					sample_size_right += (*pcnt2)[1];
				}
				pcnt0 = NULL;
				pcnt1 = NULL;
				pcnt2 = NULL;
				pcovar = NULL;
				
				if(sample_size_left < thr_leaf_size || sample_size_right < thr_leaf_size){
					
					if(debug){
						Rprintf("**************\n");
						Rprintf("node id: %d small leaves. skip the %d -th indicator\n", node.node_id, i);
					}
					
					continue;
				}
				
				if(debug){
					
					Rprintf("**************\n");
					Rprintf("node id: %d \t %d -th indicator\n", node.node_id, i);
					for(int ll = 0; ll < ngrp; ++ll){
						for(int ii = 0; ii < 3; ++ii){
							for(int jj = 0; jj < 3; ++jj){
								Rprintf("%d \t", node.cnt[ll][ii][jj]);
							}
							Rprintf("\n");
						}
						Rprintf("---------/ %d \\---------\n", ll);
					}
					
				}
				
				double score = .0;
				double var = .0;
				double r = .0;
				for(int l = 0; l < ngrp; ++l){
					r = node.cnt[l][2][1] * 1.0 / node.cnt[l][2][2];
					score += node.cnt[l][1][1] - node.cnt[l][1][2] * r;
					var += r * (1.0 - r) * node.cnt[l][1][2] / (node.cnt[l][2][2] - 1.0) * node.cnt[l][0][2];
				}
				
				double stat2by2 = score * score / var;
				if(debug){
					Rprintf("The 1-df statistics %g\n", stat2by2);
				}
				
				
				valid_node = true;
				
				if(max_split_stat <= stat2by2){
					max_split_stat = stat2by2;
					candidate_split_index = i;
					vector<int> *pcand_cnt0 = NULL;
					vector<int> *pcand_cnt1 = NULL;
					vector<int> *pcnt0 = NULL;
					vector<int> *pcnt1 = NULL;
					for(int l = 0; l < ngrp; ++l){
						pcand_cnt0 = &(node.candidate_split_cnt[l][0]);
						pcand_cnt1 = &(node.candidate_split_cnt[l][1]);
						pcnt0 = &(node.cnt[l][0]);
						pcnt1 = &(node.cnt[l][1]);
						(*pcand_cnt0)[0] = (*pcnt0)[0];
						(*pcand_cnt0)[1] = (*pcnt0)[1];
						(*pcand_cnt1)[0] = (*pcnt1)[0];
						(*pcand_cnt1)[1] = (*pcnt1)[1];
					}
					pcand_cnt0 = NULL;
					pcand_cnt1 = NULL;
					pcnt0 = NULL;
					pcnt1 = NULL;
				}
			}
		}
		
		if(valid_node){
			node.candidate_split_stat = max_split_stat;
			node.candidate_split_index = candidate_split_index;
			node.processed = true;
			node.terminal = false;
			
			return !node.terminal;
		}else{
			node.processed = true;
			node.terminal = true;
			
			return !node.terminal;
		}
	}else{
		return !node.terminal;
	}
	
	
}


bool GENE_CTREE::backward_search(vector<NODE*> &plf, vector<double> &gstat){
	
	if(debug){
		for(int i = 0; i < plf.size(); ++i){
			Rprintf("node %d\n", (*(plf[i])).node_id);
			for(int l = 0; l < ngrp; ++l){
				Rprintf("d ", (*(plf[i])).grp_nctrl[l]);
			}
			Rprintf("\n");
			for(int l = 0; l < ngrp; ++l){
				Rprintf("%d ", (*(plf[i])).grp_ncase[l]);
			}
			Rprintf("\n");
			for(int l = 0; l < ngrp; ++l){
				Rprintf("%d ", (*(plf[i])).grp_N[l]);
			}
			Rprintf("\n");
			
		}
	}
	
	int nlf = plf.size();
	
	int cnt[3][3];
	double maxDoub = 10000000000;
	int run = 1;
	vector<vector<double> > stat(nlf, vector<double>(nlf, -1.0));
	vector<bool> retNodeId(nlf, true);
	
	while(run <= nlf-2){
		
		double minStat = maxDoub;
		int id1 = -1;
		int id2 = -1;
		
		for(int i = 0; i < nlf - 1; ++i){
			for(int j = (i+1); j < nlf; ++j){
				if(stat[i][j] < 0){
					
					NODE &node_i = (*(plf[i]));
					NODE &node_j = (*(plf[j]));
					double sc = .0;
					double var = .0;
					double r = .0;
					bool err_var = false;
					
					for(int l = 0; l < ngrp; ++l){
						cnt[0][0] = node_i.grp_nctrl[l];
						cnt[0][1] = node_j.grp_nctrl[l];
						cnt[1][0] = node_i.grp_ncase[l];
						cnt[1][1] = node_j.grp_ncase[l];
						cnt[0][2] = cnt[0][0] + cnt[0][1];
						cnt[1][2] = cnt[1][0] + cnt[1][1];
						cnt[2][0] = node_i.grp_N[l];
						cnt[2][1] = node_j.grp_N[l];
						cnt[2][2] = cnt[2][0] + cnt[2][1];
						
						if(cnt[2][2] <= 1){
							sc += 0;
							var += 0;
						}else{
							r = cnt[2][1] * 1.0 / cnt[2][2];
							sc += cnt[1][1] - cnt[1][2] * r;
							var += r * (1.0 - r) * cnt[1][2] / (cnt[2][2] - 1.0) * cnt[0][2];
						}
					}
					
                           /* merge two pure nodes */
if (sc*sc < 1e-6) {
sc = .0;
 var = 1.0;
}
/* merge two pure nodes */

					stat[i][j] = sc * sc / var;
					
				}
				
				if(stat[i][j] < minStat){
					minStat = stat[i][j];
					id1 = i;
					id2 = j;
				}
			}
		}
		
		if(id1 < 0){
			error("memory issue!");
		}
		if(id2 < 0){
			error("memory issue!");
		}
		
		for(int j = id1 + 1; j < nlf; ++j){
			if(stat[id1][j] < maxDoub){
				stat[id1][j] = -1.0;
			}
		}
		for(int i = 0; i <= id1-1; ++i){
			if(stat[i][id1] < maxDoub){
				stat[i][id1] = -1.0;
			}
		}
		
		for(int i = 0; i <= id2 - 1; ++i){
			stat[i][id2] = maxDoub;
		}
		for(int j = id2 + 1; j < nlf; ++j){
			stat[id2][j] = maxDoub;
		}
		
		
		NODE &node1 = (*(plf[id1]));
		NODE &node2 = (*(plf[id2]));
		
		
		if(trace || debug){
			Rprintf("Merge nodes (%d, %d) as node %d\n", node1.node_id, node2.node_id, node1.node_id);
			Rprintf("Min stat = %g\n", minStat);
		}
		
		if(rec_model){
			vmodel.push_back(1);//0: grow tree or 1: backward
			vmodel.push_back(0);//0: NA or 1: 1-way or 2: 2-way
			vmodel.push_back(0);//indicator ID. Converted to human readable format (begin from 1 rather than 0), 0 is NA
			vmodel.push_back(node1.node_id + 1);//human readable
			vmodel.push_back(node1.node_id + 1);//human readable
			vmodel.push_back(node2.node_id + 1);//human readable
		}
		
		for(int l = 0; l < ngrp; ++l){
			node1.grp_ncase[l] += node2.grp_ncase[l];
			node1.grp_nctrl[l] += node2.grp_nctrl[l];
			node1.grp_N[l] += node2.grp_N[l];
			node1.node_id = node1.node_id < node2.node_id ? node1.node_id : node2.node_id;
		}
		node1.N += node2.N;
		retNodeId[id2] = false;
		vector<NODE*> pRetLf;
		for(int i = 0; i < nlf; ++i){
			if(retNodeId[i]){
				pRetLf.push_back(plf[i]);
			}
		}
		
		global_test(pRetLf, gstat[nlf-2-run]);
		
		if(trace || debug){
			Rprintf("Global stat = %g\n", gstat[nlf-2-run]);
			Rprintf("---------------------------------------------------\n");
		}
		
		++run;
	}
	
	
}

//this function has not been optimized. It is just used for double check
bool GENE_CTREE::backward_search1(vector<NODE*> &plf, vector<double> &gstat){
	
	int nlf = plf.size();
	
	int cnt[3][3];
	double maxDoub = 10000000000;
	int run = 1;
	vector<vector<double> > stat(nlf, vector<double>(nlf, -1.0));
	vector<bool> retNodeId(nlf, true);
	
	while(run <= nlf-2){
		
		double minStat = maxDoub;
		int id1 = -1;
		int id2 = -1;
		
		for(int i = 0; i < nlf - 1; ++i){
			for(int j = (i+1); j < nlf; ++j){
				if(retNodeId[i] && retNodeId[j]){
					
					NODE &node_i = (*(plf[i]));
					NODE &node_j = (*(plf[j]));
					double sc = .0;
					double var = .0;
					double r = .0;
					bool err_var = false;
					
					for(int l = 0; l < ngrp; ++l){
						cnt[0][0] = node_i.grp_nctrl[l];
						cnt[0][1] = node_j.grp_nctrl[l];
						cnt[1][0] = node_i.grp_ncase[l];
						cnt[1][1] = node_j.grp_ncase[l];
						cnt[0][2] = cnt[0][0] + cnt[0][1];
						cnt[1][2] = cnt[1][0] + cnt[1][1];
						cnt[2][0] = node_i.grp_N[l];
						cnt[2][1] = node_j.grp_N[l];
						cnt[2][2] = cnt[2][0] + cnt[2][1];
						
						if(cnt[2][2] <= 1){
							sc += 0;
							var += 0;
						}else{
							r = cnt[2][1] * 1.0 / cnt[2][2];
							sc += cnt[1][1] - cnt[1][2] * r;
							var += r * (1.0 - r) * cnt[1][2] / (cnt[2][2] - 1.0) * cnt[0][2];
						}
					}
					
					stat[i][j] = sc * sc / var;
					
				}else{
					stat[i][j] = maxDoub;
				}
				
				if(stat[i][j] < minStat){
					minStat = stat[i][j];
					id1 = i;
					id2 = j;
				}
			}
		}
		
		if(id1 < 0){
			error("memory issue!");
		}
		if(id2 < 0){
			error("memory issue!");
		}
		
		if(trace){
			for(int i = 0; i < nlf; ++i){
				for(int j = 0; j < nlf; ++j){
					if(i >= j){
						Rprintf("0\t");
					}else{
						Rprintf("%g\t", stat[i][j]);
					}
				}
				Rprintf("\n");
			}
			Rprintf("=====================\n");
		}
		
		
		NODE &node1 = (*(plf[id1]));
		NODE &node2 = (*(plf[id2]));
		
		
		if(trace || debug){
			Rprintf("Merge nodes (%d, %d) as node %d\n", node1.node_id , node2.node_id, node1.node_id);
			Rprintf("Min stat = %g\n", minStat);
		}
		
		for(int l = 0; l < ngrp; ++l){
			node1.grp_ncase[l] += node2.grp_ncase[l];
			node1.grp_nctrl[l] += node2.grp_nctrl[l];
			node1.grp_N[l] += node2.grp_N[l];
			node1.node_id = node1.node_id < node2.node_id ? node1.node_id : node2.node_id;
		}
		node1.N += node2.N;
		retNodeId[id2] = false;
		vector<NODE*> pRetLf;
		for(int i = 0; i < nlf; ++i){
			if(retNodeId[i]){
				pRetLf.push_back(plf[i]);
			}
		}
		
		global_test(pRetLf, gstat[nlf-2-run]);
		
		if(trace || debug){
			Rprintf("Global stat = %g\n", gstat[nlf-2-run]);
			Rprintf("---------------------------------------------------\n");
		}
		
		++run;
	}
	
	
}

void GENE_CTREE::destroy_tree(vector<NODE*> &pointer){
	
	for(int i = 0; i < pointer.size(); ++i){
		if(pointer[i]){
			delete pointer[i];
			pointer[i] = NULL;
		}
	}
	
}


void GENE_CTREE::print_table(const NODE &node){
	
	Rprintf("\nNode\t# %d \t # %d\n", (*(node.child1)).node_id, (*(node.child2)).node_id);
	Rprintf("CTRL\t%d\t%d\n", (*(node.child1)).nctrl, (*(node.child2)).nctrl);
	Rprintf("CASE\t%d\t%d\n", (*(node.child1)).ncase, (*(node.child2)).ncase);
	Rprintf("\n");
	
}


void GENE_CTREE::grow_tree(vector<double> &gstat, vector<double> &gstatBack){//global statistics
	
	if(!gstat.empty()){
		gstat.clear();
	}
	gstat.reserve(nleaf);
	
	if(!gstatBack.empty()){
		gstatBack.clear();
	}
	gstatBack.reserve(nleaf);
	
	//NODE(const bitvec &input_sample_index, const vector<bool> &input_valid_indicator, 
	//vector<int> input_grp_ncase, vector<int> input_grp_nctrl, 
	//int input_node_id, int input_split_idx, int input_candidate_split_index, 
	//bool input_processed, bool input_terminal, double input_candidate_split_stat, 
	//NODE *const par, NODE *const chd1, NODE *const chd2)
	vector<NODE*> all_allocate_node;
	all_allocate_node.reserve(50);
	vector<NODE*> pointer_leaf;
	pointer_leaf.reserve(nleaf);
	vector<bool> valid_indicator(nind, true);
	for(int j = 0; j < nind; ++j){
		if(ind_N[j] < thr_leaf_size){
			valid_indicator[j] = false;
		}
	}
	
	int node_id = 0;
	NODE *root = new NODE(all_one, valid_indicator, grp_ncase, grp_nctrl, node_id, -1, -1, false, false, -1.0, NULL, NULL, NULL);
	pointer_leaf.push_back(root);
	all_allocate_node.push_back(root);
	
	while(pointer_leaf.size() < nleaf){
		
		double max_stat = -1.0;
		bool valid = false;
		int sel_leaf = -1;
		
		for(int i = 0; i < pointer_leaf.size(); ++i){
			
			NODE &node = *(pointer_leaf[i]);
			if(node.N < thr_sample){
				if(debug){
					Rprintf("Too small sample size in node %d\n", node.node_id);
				}
				continue;
			}
			
			if(group_split(node)){
				
				valid = true;
				if(debug){
					Rprintf("candidate %g\n", node.candidate_split_stat);
				}
				if(node.candidate_split_stat > max_stat){
					max_stat = node.candidate_split_stat;
					sel_leaf = i;
				}
			}
		}
		
		if(!valid){
			if(debug || trace){
				Rprintf("All the nodes cannot be split\n");
			}
			break;
		}
		
		NODE &node = (*(pointer_leaf[sel_leaf]));
		

		node.split_index = node.candidate_split_index;
		
		if(debug || trace){
			Rprintf("Split node %d to nodes (%d, %d) by 1-way indicator %d\n", node.node_id, node_id+1, node_id+2, node.split_index);
			Rprintf("Max stat = %g\n", max_stat);
		}
		
		if(rec_model){
			vmodel.push_back(0);//0: grow tree or 1: backward
			vmodel.push_back(1);//1: 1-way or 2: 2-way
			vmodel.push_back(node.split_index + 1);//indicator ID. Converted to human readable format (begin from 1 rather than 0)
			vmodel.push_back(node.node_id + 1);//human readable
			vmodel.push_back(node_id + 2);//human readable
			vmodel.push_back(node_id + 3);//human readable
		}
		
		bitvec sample_index_child1 (nblock, (uint64) 0);
		bitvec sample_index_child2 (nblock, (uint64) 0);
		bitvec *pind_sel = &(indicator64[node.split_index]);
		bitvec *pnot_ind_sel = &(not_indicator64[node.split_index]);
		for(int j = 0; j < nblock; ++j){
			sample_index_child1[j] = node.sample_index[j] & (*pind_sel)[j];
			sample_index_child2[j] = node.sample_index[j] & (*pnot_ind_sel)[j];
		}
		
		vector<int> grp_ncase1(ngrp, 0);
		vector<int> grp_ncase2(ngrp, 0);
		vector<int> grp_nctrl1(ngrp, 0);
		vector<int> grp_nctrl2(ngrp, 0);
		vector<int> *pcand_cnt0 = NULL;
		vector<int> *pcand_cnt1 = NULL;
		for(int l = 0; l < ngrp; ++l){
			pcand_cnt0 = &(node.candidate_split_cnt[l][0]);
			pcand_cnt1 = &(node.candidate_split_cnt[l][1]);
			grp_nctrl1[l] = (*pcand_cnt0)[1];
			grp_nctrl2[l] = (*pcand_cnt0)[0];
			grp_ncase1[l] = (*pcand_cnt1)[1];
			grp_ncase2[l] = (*pcand_cnt1)[0];
		}
		
		//NODE(const bitvec &input_sample_index, const vector<bool> &input_valid_indicator, 
		//vector<int> input_grp_ncase, vector<int> input_grp_nctrl, 
		//int input_node_id, int input_split_idx, int input_candidate_split_index, 
		//bool input_processed, bool input_terminal, double input_candidate_split_stat, 
		//NODE *const par, NODE *const chd1, NODE *const chd2)
		node_id++;
		NODE *pchild1 = new NODE(sample_index_child1, node.valid_indicator, grp_ncase1, grp_nctrl1, node_id, -1, -1, false, false, -1.0, &node, NULL, NULL);
		node_id++;
		NODE *pchild2 = new NODE(sample_index_child2, node.valid_indicator, grp_ncase2, grp_nctrl2, node_id, -1, -1, false, false, -1.0, &node, NULL, NULL);
		node.child1 = pchild1;
		node.child2 = pchild2;
		
		all_allocate_node.push_back(pchild1);
		all_allocate_node.push_back(pchild2);
		
		pointer_leaf.erase(pointer_leaf.begin()+sel_leaf);
		
		pointer_leaf.push_back(pchild1);
		pointer_leaf.push_back(pchild2);
		
		double stat;
		global_test(pointer_leaf, stat);
		
		if(debug || trace){
			Rprintf("Global stat = %g\n", stat);
			Rprintf("---------------------------------------------------\n");
		}
		gstat.push_back(stat);
		
	}
	
	if(debug){
		Rprintf("gstat before\n");
		/*Rprintf("%g\n", gstat);*/
	}
	
	gstatBack = gstat;
	if(backward){
		backward_search(pointer_leaf, gstatBack);
	}
	
	if(debug){
		Rprintf("gstat after\n");
		/*Rprintf("%g\n", gstatBack);*/
	}
	
	
	destroy_tree(all_allocate_node);
	if(debug || trace){
		Rprintf("The tree is grown and destroyed\n");
		Rprintf("---------------------------------------------------\n");
	}
	
}

void GENE_CTREE::grow_tree2(vector<double> &gstat, vector<double> &gstatBack){//global statistics
	
	if(!gstat.empty()){
		gstat.clear();
	}
	gstat.reserve(nleaf);
	
	if(!gstatBack.empty()){
		gstatBack.clear();
	}
	gstatBack.reserve(nleaf);
	
	//NODE(const bitvec &input_sample_index, const vector<bool> &input_valid_indicator, 
	//vector<int> input_grp_ncase, vector<int> input_grp_nctrl, 
	//int input_node_id, int input_split_idx, int input_candidate_split_index, 
	//bool input_processed, bool input_terminal, double input_candidate_split_stat, 
	//NODE *const par, NODE *const chd1, NODE *const chd2)
	vector<NODE*> all_allocate_node;
	all_allocate_node.reserve(50);
	vector<NODE*> pointer_leaf;
	pointer_leaf.reserve(nleaf);
	vector<bool> valid_indicator(nind, true);
	for(int j = 0; j < nind; ++j){
		if(ind_N[j] < thr_leaf_size){
			valid_indicator[j] = false;
		}
	}
	
	int node_id = 0;
	NODE *root = new NODE(all_one, valid_indicator, grp_ncase, grp_nctrl, node_id, -1, -1, false, false, -1.0, NULL, NULL, NULL);
	pointer_leaf.push_back(root);
	all_allocate_node.push_back(root);
	
	
	bool valid_first_split = false;
	
	//process the root by different strategy

	NODE &node = *root;
	if(node.N < thr_sample){
		if(debug){
			Rprintf("Too small sample size in node %d\n", node.node_id);
		}
	}
	
	if(group_split2(node)){
		
		if(debug){
			Rprintf("candidate %g\n", node.candidate_split_stat);
		}
		valid_first_split = true;
	}else{
		Rprintf("cannot split the root\n");
		valid_first_split = false;
	}
  
	if(valid_first_split){
		node.split_index = node.candidate_split_index;
		
		if(debug || trace){
			Rprintf("\n---------------------------------------------\n");
			Rprintf("Details when growing tree on observed dataset\n");
			Rprintf("---------------------------------------------\n");
			
			Rprintf("Split node %d to nodes (%d, %d) by 2-way indicaotr %d\n", node.node_id, node_id+1, node_id+2, node.split_index);
			Rprintf("Max stat = %g\n", node.candidate_split_stat);
		}
		
		if(rec_model){
			vmodel.push_back(0);//0: grow tree or 1: backward
			vmodel.push_back(2);//1: 1-way or 2: 2-way
			vmodel.push_back(node.split_index + 1);//indicator ID. Converted to human readable format (begin from 1 rather than 0)
			vmodel.push_back(node.node_id + 1);//human readable
			vmodel.push_back(node_id + 2);//human readable
			vmodel.push_back(node_id + 3);//human readable
		}
		
		bitvec sample_index_child1 (nblock, (uint64) 0);
		bitvec sample_index_child2 (nblock, (uint64) 0);
		bitvec *pind_sel = &(two_way_indicator64[node.split_index]);
		bitvec *pnot_ind_sel = &(two_way_not_indicator64[node.split_index]);
		for(int j = 0; j < nblock; ++j){
			sample_index_child1[j] = node.sample_index[j] & (*pind_sel)[j];
			sample_index_child2[j] = node.sample_index[j] & (*pnot_ind_sel)[j];
		}
		
		vector<int> grp_ncase1(ngrp, 0);
		vector<int> grp_ncase2(ngrp, 0);
		vector<int> grp_nctrl1(ngrp, 0);
		vector<int> grp_nctrl2(ngrp, 0);
		vector<int> *pcand_cnt0 = NULL;
		vector<int> *pcand_cnt1 = NULL;
		for(int l = 0; l < ngrp; ++l){
			pcand_cnt0 = &(node.candidate_split_cnt[l][0]);
			pcand_cnt1 = &(node.candidate_split_cnt[l][1]);
			grp_nctrl1[l] = (*pcand_cnt0)[1];
			grp_nctrl2[l] = (*pcand_cnt0)[0];
			grp_ncase1[l] = (*pcand_cnt1)[1];
			grp_ncase2[l] = (*pcand_cnt1)[0];
		}
		
		//NODE(const bitvec &input_sample_index, const vector<bool> &input_valid_indicator, 
		//vector<int> input_grp_ncase, vector<int> input_grp_nctrl, 
		//int input_node_id, int input_split_idx, int input_candidate_split_index, 
		//bool input_processed, bool input_terminal, double input_candidate_split_stat, 
		//NODE *const par, NODE *const chd1, NODE *const chd2)
		valid_indicator = node.valid_indicator;
		node_id++;
		NODE *pchild1 = new NODE(sample_index_child1, valid_indicator, grp_ncase1, grp_nctrl1, node_id, -1, -1, false, false, -1.0, &node, NULL, NULL);
		node_id++;
		NODE *pchild2 = new NODE(sample_index_child2, valid_indicator, grp_ncase2, grp_nctrl2, node_id, -1, -1, false, false, -1.0, &node, NULL, NULL);
		node.child1 = pchild1;
		node.child2 = pchild2;
		
		if(trace){
			print_table(node);
		}
		
		all_allocate_node.push_back(pchild1);
		all_allocate_node.push_back(pchild2);
		
		pointer_leaf.pop_back();
		
		pointer_leaf.push_back(pchild1);
		pointer_leaf.push_back(pchild2);
		
		double stat;
		global_test(pointer_leaf, stat);
		
		if(debug || trace){
			Rprintf("Global stat = %g\n", stat);
			Rprintf("---------------------------------------------------\n");
		}
		gstat.push_back(stat);
	}
	
	if(valid_first_split){
		while(pointer_leaf.size() < nleaf){
			
			double max_stat = -1.0;
			bool valid = false;
			int sel_leaf = -1;
			
			for(int i = 0; i < pointer_leaf.size(); ++i){
				
				NODE &node = *(pointer_leaf[i]);
				if(node.N < thr_sample){
					if(debug){
						Rprintf("Too small sample size in node %d\n", node.node_id);
					}
					continue;
				}
				
				if(group_split(node)){
					
					valid = true;
					if(debug){
						Rprintf("candidate %d\n", node.candidate_split_stat);
					}
					if(node.candidate_split_stat > max_stat){
						max_stat = node.candidate_split_stat;
						sel_leaf = i;
					}
				}
			}
			
			if(!valid){
				if(debug || trace){
					Rprintf("All the nodes cannot be split\n");
				}
				break;
			}
			
			NODE &node = (*(pointer_leaf[sel_leaf]));
			
  	
			node.split_index = node.candidate_split_index;
			
			if(debug || trace){
				Rprintf("Split node %d to nodes (%d, %d) by 1-way indicator %d\n", node.node_id, node_id+1, node_id+2, node.split_index);
				Rprintf("Max stat = %g\n", max_stat);
			}
			
			if(rec_model){
				vmodel.push_back(0);//0: grow tree or 1: backward
				vmodel.push_back(1);//1: 1-way or 2: 2-way
				vmodel.push_back(node.split_index + 1);//indicator ID. Converted to human readable format (begin from 1 rather than 0)
				vmodel.push_back(node.node_id + 1);//human readable
				vmodel.push_back(node_id + 2);//human readable
				vmodel.push_back(node_id + 3);//human readable
			}
			
			bitvec sample_index_child1 (nblock, (uint64) 0);
			bitvec sample_index_child2 (nblock, (uint64) 0);
			bitvec *pind_sel = &(indicator64[node.split_index]);
			bitvec *pnot_ind_sel = &(not_indicator64[node.split_index]);
			for(int j = 0; j < nblock; ++j){
				sample_index_child1[j] = node.sample_index[j] & (*pind_sel)[j];
				sample_index_child2[j] = node.sample_index[j] & (*pnot_ind_sel)[j];
			}
			
			vector<int> grp_ncase1(ngrp, 0);
			vector<int> grp_ncase2(ngrp, 0);
			vector<int> grp_nctrl1(ngrp, 0);
			vector<int> grp_nctrl2(ngrp, 0);
			vector<int> *pcand_cnt0 = NULL;
			vector<int> *pcand_cnt1 = NULL;
			for(int l = 0; l < ngrp; ++l){
				pcand_cnt0 = &(node.candidate_split_cnt[l][0]);
				pcand_cnt1 = &(node.candidate_split_cnt[l][1]);
				grp_nctrl1[l] = (*pcand_cnt0)[1];
				grp_nctrl2[l] = (*pcand_cnt0)[0];
				grp_ncase1[l] = (*pcand_cnt1)[1];
				grp_ncase2[l] = (*pcand_cnt1)[0];
			}
			
			//NODE(const bitvec &input_sample_index, const vector<bool> &input_valid_indicator, 
			//vector<int> input_grp_ncase, vector<int> input_grp_nctrl, 
			//int input_node_id, int input_split_idx, int input_candidate_split_index, 
			//bool input_processed, bool input_terminal, double input_candidate_split_stat, 
			//NODE *const par, NODE *const chd1, NODE *const chd2)
			
			valid_indicator = node.valid_indicator;
			valid_indicator[node.split_index] = false;
			node_id++;
			NODE *pchild1 = new NODE(sample_index_child1, valid_indicator, grp_ncase1, grp_nctrl1, node_id, -1, -1, false, false, -1.0, &node, NULL, NULL);
			node_id++;
			NODE *pchild2 = new NODE(sample_index_child2, valid_indicator, grp_ncase2, grp_nctrl2, node_id, -1, -1, false, false, -1.0, &node, NULL, NULL);
			node.child1 = pchild1;
			node.child2 = pchild2;
			
			if(trace){
				print_table(node);
			}
			
			all_allocate_node.push_back(pchild1);
			all_allocate_node.push_back(pchild2);
			
			pointer_leaf.erase(pointer_leaf.begin()+sel_leaf);
			
			pointer_leaf.push_back(pchild1);
			pointer_leaf.push_back(pchild2);
			
			double stat;
			global_test(pointer_leaf, stat);
			
			if(debug || trace){
				Rprintf("Global stat = %g\n", stat);
				Rprintf("---------------------------------------------------\n");
			}
			gstat.push_back(stat);
			
		}   
	}
	
	if(debug){
		Rprintf("gstat before\n");
		/*Rprintf("%g\n", gstat);*/
	}
	
	gstatBack = gstat;
	if(backward){
		backward_search(pointer_leaf, gstatBack);
	}
	
	if(debug){
		Rprintf("gstat after\n");
		/*Rprintf("%g\n", gstatBack);*/
	}
	
	destroy_tree(all_allocate_node);
	if(debug || trace){
		Rprintf("The tree is grown and destroyed\n");
		Rprintf("---------------------------------------------------\n");
	}
	
}




vector<int> GENE_CTREE::bit2int(const bitvec &bv){

	vector<int> iv;
	for(int i = 0; i < bv.size(); ++i){
		for(int k = 0; k < LEN_LONG; ++k){
			iv.push_back((bv[i] & (MASK >> k)) >> (LEN_LONG - k - 1));
		}
	}

	return iv;

}


void GENE_CTREE::swap(bitvec &v, int k1, int k2){

	int d = offset[k2] - offset[k1];
	if(d < 0){
		k1 ^= k2;
		k2 ^= k1;
		k1 ^= k2;
		d = -d;
	}

	uint64 v1 = (v[bitloc[k1]] & MASK_offset[k1]) >> d;
	uint64 v2 = (v[bitloc[k2]] & MASK_offset[k2]) << d;
	v[bitloc[k1]] &= not_MASK_offset[k1];
	v[bitloc[k2]] &= not_MASK_offset[k2];
	v[bitloc[k1]] |= v2;
	v[bitloc[k2]] |= v1;

}


void GENE_CTREE::permutation(){

	for(int k = N - 1; k > 0; --k){
		int j = rand() % (k + 1);
		swap(y64, j, k);
	}
	
	for(int i = 0; i < nblock; ++i){
		not_y64[i] = ~y64[i];
	}

}

void GENE_CTREE::permute_by_covar(){
	
	for(int l = 0; l < ngrp; ++l){
		int n_in_grp = grp_N[l];
		vector<int> *pcovar_idx = &(covar_idx[l]);
		for(int k = n_in_grp - 1; k > 0; --k){
			int j = rand() % (k + 1);
			swap(y64, (*pcovar_idx)[j], (*pcovar_idx)[k]);
		}
	}
	
	for(int i = 0; i < nblock; ++i){
		not_y64[i] = ~y64[i];
	}
	
}

void GENE_CTREE::test_tree(){
	
	sort(cut_point.begin(), cut_point.end());
	global_stat = vector<VecScore> (ncp, VecScore(nperm + 1, score0));
	global_stat_back = vector<VecScore> (ncp, VecScore(nperm + 1, score0));
	vector<double> gst;
	vector<double> gstBack;
	gst.reserve(ncp);
	gstBack.reserve(ncp);
	rec_model = true;
	if(two_way){
		grow_tree2(gst, gstBack);
	}else{
		grow_tree(gst, gstBack);
	}
	
	if(gst.empty()){
           error("Cannot grow the tree. Please debug the code\n");
        
	}
	
	if(backward && gstBack.empty()){
		error("Error occurs in backward merging. Please debug the code");
	}
	
	double last_stat0;
	for(int ii = 0; ii < ncp; ++ii){
		if(cut_point[ii] < gst.size()){
			global_stat[ii][0].score = gst[cut_point[ii]];
			global_stat[ii][0].id = 0;
			last_stat0 = gst[cut_point[ii]];
		}else{
			global_stat[ii][0].score = last_stat0;
			global_stat[ii][0].id = 0;
		}
	}
	
	if(backward){
		double last_stat0_back;
		for(int ii = 0; ii < ncp; ++ii){
			if(cut_point[ii] < gstBack.size()){
				global_stat_back[ii][0].score = gstBack[cut_point[ii]];
				global_stat_back[ii][0].id = 0;
				last_stat0_back = gstBack[cut_point[ii]];
			}else{
				global_stat_back[ii][0].score = last_stat0_back;
				global_stat_back[ii][0].id = 0;
			}
		}
	}
	
	for(int i = 0; i < vmodel.size(); ++i){
		model[i] = vmodel[i];
	}
	
	debug = false;
	trace = false;
	bool early_stop = false;
	rec_model = false;
	for(int i = 1; i < nperm + 1; ++i){
		
		permute_by_covar();
		if(two_way){
			grow_tree2(gst, gstBack);
		}else{
			grow_tree(gst, gstBack);
		}
		
		if(gst.empty()){
			Rprintf("Cannot grow the tree at the %d -th iteration. Please debug the code\n", i);
			error("1");
		}
		
		if(backward && gstBack.empty()){
			Rprintf("Error occurs in backward merging at the %d -th iteration. Please debug the code\n", i);
			error("1");
		}
		
		double last_stat;
		for(int ii = 0; ii < ncp; ++ii){
			if(cut_point[ii] < gst.size()){
				global_stat[ii][i].score = gst[cut_point[ii]];
				global_stat[ii][i].id = i;
				last_stat = gst[cut_point[ii]];
			}else{
				global_stat[ii][i].score = last_stat;
				global_stat[ii][i].id = i;
			}
		}
		
		if(backward){
			double last_stat_back;
			for(int ii = 0; ii < ncp; ++ii){
				if(cut_point[ii] < gstBack.size()){
					global_stat_back[ii][i].score = gstBack[cut_point[ii]];
					global_stat_back[ii][i].id = i;
					last_stat_back = gstBack[cut_point[ii]];
				}else{
					global_stat_back[ii][i].score = last_stat_back;
					global_stat_back[ii][i].id = i;
				}
			}
		}
		
		if(i == 1000 && cal_pval){
			try_calculate_pvalue(i);
			if(try_adj_pval > 0.15){
				adj_pval = try_adj_pval;
				unadj_pval = try_unadj_pval;
				if(backward){
					adj_pval_back = try_adj_pval_back;
					unadj_pval_back = try_unadj_pval_back;
				}
				early_stop = true;
				if(debug || trace){
					Rprintf("Insignificant p-value detected\n");
					Rprintf("Early stop\n");
					Rprintf("---------------------------------------------------\n");
				}
				break;
			}
		}
	}
	
	if(cal_pval){
		if(!early_stop){
			calculate_pvalue();
		}
	}else{
		if(bin){
			store_binary();
		}else{
			store();
		}
	}
	
	get_pvalue();
	
}



void GENE_CTREE::try_calculate_pvalue(const int &nperm_try){
	
	vector<VecScore> try_global_stat = vector<VecScore> (ncp, VecScore(nperm_try + 1, score0));
	for(int j = 0; j < ncp; ++j){
		for(int i = 0; i < nperm_try+1; ++i){
			try_global_stat[j][i].score = global_stat[j][i].score;
			try_global_stat[j][i].id = global_stat[j][i].id;
		}
	}
	
	vector<vector<int> > arr_rank(ncp, vector<int> (nperm_try+1,0));
	for(int j = 0; j < ncp; ++j){
		sort(try_global_stat[j].begin(), try_global_stat[j].end());
		for(int i = 0; i < nperm_try + 1; ++i){
			int id = try_global_stat[j][i].id;
			arr_rank[j][id] = i;
		}
	}
	
	vector<VecScore> tmp_gst;
	try_global_stat.swap(tmp_gst);
	
	try_unadj_pval = vector<double> (ncp, -1.0);
	for(int j = 0; j < ncp; ++j){
		try_unadj_pval[j] = 1.0 -arr_rank[j][0] * 1.0 /(nperm_try+1);
	}
	
	vector<int> max_rk(nperm_try+1, 0);
	for(int i = 0; i < nperm_try+1; ++i){
		int mrk = -1;
		for(int j = 0; j < ncp; ++j){
			if(arr_rank[j][i] > mrk){
				mrk = arr_rank[j][i];
			}
		}
		max_rk[i] = mrk;
	}
	
	vector<vector<int> > tmp_ark;
	arr_rank.swap(tmp_ark);
	
	int max_rank = max_rk[0];
	int npval = 1;
	for(int i = 1; i < nperm_try + 1; ++i){
		if(max_rk[i] >= max_rank){
			npval++;
		}
	}
	
	try_adj_pval = npval *1.0/(nperm_try + 1);
	
	
	////////////////
	
	if(backward){
		
		vector<VecScore> try_global_stat_back = vector<VecScore> (ncp, VecScore(nperm_try + 1, score0));
		for(int j = 0; j < ncp; ++j){
			for(int i = 0; i < nperm_try+1; ++i){
				try_global_stat_back[j][i].score = global_stat_back[j][i].score;
				try_global_stat_back[j][i].id = global_stat_back[j][i].id;
			}
		}
		
		vector<vector<int> > arr_rank_back(ncp, vector<int>(nperm_try+1,0));
		for(int j = 0; j < ncp; ++j){
			sort(try_global_stat_back[j].begin(), try_global_stat_back[j].end());
			for(int i = 0; i < nperm_try + 1; ++i){
				int id = try_global_stat_back[j][i].id;
				arr_rank_back[j][id] = i;
			}
		}
		
		vector<VecScore> tmp_gst_back;
		try_global_stat_back.swap(tmp_gst_back);
		
		try_unadj_pval_back = vector<double> (ncp, -1.0);
		for(int j = 0; j < ncp; ++j){
			try_unadj_pval_back[j] = 1.0 -arr_rank_back[j][0] * 1.0 /(nperm_try+1);
		}
		
		vector<int> max_rk_back(nperm_try+1, 0);
		for(int i = 0; i < nperm_try+1; ++i){
			int mrk = -1;
			for(int j = 0; j < ncp; ++j){
				if(arr_rank_back[j][i] > mrk){
					mrk = arr_rank_back[j][i];
				}
			}
			max_rk_back[i] = mrk;
		}
		
		vector<vector<int> > tmp_ark_back;
		arr_rank_back.swap(tmp_ark_back);
		
		int max_rank_back = max_rk_back[0];
		int npval_back = 1;
		for(int i = 1; i < nperm_try + 1; ++i){
			if(max_rk_back[i] >= max_rank_back){
				npval_back++;
			}
		}
		
		try_adj_pval_back = npval_back *1.0/(nperm_try + 1);
	}
	
}


void GENE_CTREE::calculate_pvalue(){
	
	/*
	cout << "gstat" << endl;
	for(int j = 0; j < ncp; ++j){
		for(int i = 0; i < nperm+1; ++i){
			cout << global_stat[j][i].score << "\t";
		}
		cout << endl;
	}
	
	
	cout << "gstat back" << endl;
	for(int j = 0; j < ncp; ++j){
		for(int i = 0; i < nperm+1; ++i){
			cout << global_stat_back[j][i].score << "\t";
		}
		cout << endl;
	}
	*/
	
	vector<vector<int> > arr_rank(ncp, vector<int> (nperm+1,0));
	for(int j = 0; j < ncp; ++j){
		sort(global_stat[j].begin(), global_stat[j].end());
		for(int i = 0; i < nperm + 1; ++i){
			int id = global_stat[j][i].id;
			arr_rank[j][id] = i;
		}
	}
	
	vector<VecScore> tmp_gst;
	global_stat.swap(tmp_gst);
	
	unadj_pval = vector<double> (ncp, -1.0);
	for(int j = 0; j < ncp; ++j){
		unadj_pval[j] = 1.0-arr_rank[j][0] * 1.0/(nperm+1);
	}
	
	vector<int> max_rk(nperm+1, 0);
	for(int i = 0; i < nperm+1; ++i){
		int mrk = -1;
		for(int j = 0; j < ncp; ++j){
			if(arr_rank[j][i] > mrk){
				mrk = arr_rank[j][i];
			}
		}
		max_rk[i] = mrk;
	}
	
	vector<vector<int> > tmp_ark;
	arr_rank.swap(tmp_ark);
	
	int max_rank = max_rk[0];
	int npval = 1;
	for(int i = 1; i < nperm + 1; ++i){
		if(max_rk[i] >= max_rank){
			npval++;
		}
	}
	
	adj_pval = npval *1.0/(nperm + 1);
	
	////////
	
	if(backward){
		
		vector<vector<int> > arr_rank_back(ncp, vector<int>(nperm+1,0));
		for(int j = 0; j < ncp; ++j){
			sort(global_stat_back[j].begin(), global_stat_back[j].end());
			for(int i = 0; i < nperm+1; ++i){
				int id = global_stat_back[j][i].id;
				arr_rank_back[j][id] = i;
			}
		}
		
		vector<VecScore> tmp_gst_back;
		global_stat_back.swap(tmp_gst_back);
		
		unadj_pval_back = vector<double> (ncp, -1.0);
		for(int j = 0; j < ncp; ++j){
			unadj_pval_back[j] = 1.0-arr_rank_back[j][0] * 1.0/(nperm+1);
		}
		
		vector<int> max_rk_back(nperm+1, 0);
		for(int i = 0; i < nperm+1; ++i){
			int mrk = -1;
			for(int j = 0; j < ncp; ++j){
				if(arr_rank_back[j][i] > mrk){
					mrk = arr_rank_back[j][i];
				}
			}
			max_rk_back[i] = mrk;
		}
		
		vector<vector<int> > tmp_ark_back;
		arr_rank_back.swap(tmp_ark_back);
		
		int max_rank_back = max_rk_back[0];
		int npval_back = 1;
		for(int i = 1; i < nperm + 1; ++i){
			if(max_rk_back[i] >= max_rank_back){
				npval_back++;
			}
		}
		
		adj_pval_back = npval_back *1.0/(nperm + 1);
	}
	
}

void GENE_CTREE::store(){
	
	ofstream fout;
	fout.open(path_output, ios::out);
	if(!fout){
		Rprintf("Error: cannot open output file: %s", path_output);
		error("1");
	}
	
	for(int i = 0; i < nperm + 1; ++i){
		for(int j = 0; j < ncp; ++j){
			fout << global_stat[j][i].score << "\t";
		}
		fout << endl;
		if(i % 1000 == 0){
			fout.flush();
		}
	}
	fout.flush();
	fout.close();
	
	if(backward){
		ofstream fout;
		fout.open(path_output_back, ios::out);
		if(!fout){
			Rprintf("Error: cannot open output file: %s", path_output);
			error("1");
		}
		
		for(int i = 0; i < nperm + 1; ++i){
			for(int j = 0; j < ncp; ++j){
				fout << global_stat_back[j][i].score << "\t";
			}
			fout << endl;
			if(i % 1000 == 0){
				fout.flush();
			}
		}
		fout.flush();
		fout.close();
	}
	
}


void GENE_CTREE::store_binary(){
	
	fstream fout;
	fout.open(path_output, ios::out | ios::binary);
	if(!fout){
		Rprintf("Error: cannot open output file: %s", path_output);
		error("1");
	}
	
	double dnperm = (double) nperm;
	double dncp = (double) ncp;
	fout.write((char*)(&dnperm), sizeof(dnperm));
	fout.write((char*)(&dncp), sizeof(dncp));
	
	for(int i = 0; i < nperm + 1; ++i){
		for(int j = 0; j < ncp; ++j){
			fout.write((char*)(&(global_stat[j][i].score)), sizeof(global_stat[j][i].score));
		}
//		if(i % 1000 == 0){
//			fout.flush();
//		}
	}
//	fout.flush();
	fout.close();
	
	if(backward){
		fstream fout;
		fout.open(path_output_back, ios::out | ios::binary);
		if(!fout){
			Rprintf("Error: cannot open output file: %s", path_output);
			error("1");
		}
		
		fout.write((char*)(&nperm), sizeof(nperm));
		fout.write((char*)(&ncp), sizeof(ncp));
		for(int i = 0; i < nperm + 1; ++i){
			for(int j = 0; j < ncp; ++j){
				fout.write((char*)(&(global_stat_back[j][i].score)), sizeof(global_stat_back[j][i].score));
			}
//			if(i % 1000 == 0){
//				fout.flush();
//			}
		}
//		fout.flush();
		fout.close();
	}
	
}

void GENE_CTREE::get_pvalue(){
	
	if(cal_pval){
		pval[0] = adj_pval;
		for(int j = 0; j < ncp; ++j){
			pval[j+1] = unadj_pval[j];
		}
		
		if(backward){
			pval_back[0] = adj_pval_back;
			for(int j = 0; j < ncp; ++j){
				pval_back[j+1] = unadj_pval_back[j];
			}
		}
		
	}else{
		pval[0] = -1;
		for(int j = 0; j < ncp; ++j){
			pval[j+1] = -1;
		}
		
		if(backward){
			pval_back[0] = -1;
			for(int j = 0; j < ncp; ++j){
				pval_back[j+1] = -1;
			}
		}
	}
	
}


extern "C" {
	
void gene_ctree3(int * const input_data, int * const input_data2, int * const input_covar, 
const int *input_two_way, const int *input_backward, const int *input_cal_pval, char **input_path_output, 
char **input_path_output_back, const int * input_nsample, const int * input_ngrp, const int *input_nind, 
const int *input_nind2, const int *input_thr_sample, const int *input_thr_grp_sample_size, 
const int *input_thr_leaf_size, const int *input_nleaf, int * const input_cut_point, 
const int *input_ncp, const int *input_nperm, const int *input_trace, const int *input_seed, 
const int *input_debug, const int *input_bin, double *pval, double *pval_back, int *model){
	
	int * const data = input_data;
	int * const data2 = input_data2;
	int * const covar = input_covar;
	const bool two_way = *input_two_way != 0 ? true : false;
	const bool backward = *input_backward !=0 ? true : false;
	const bool cal_pval = *input_cal_pval != 0 ? true : false;
	const int N = *input_nsample;
	int * const cut_point = input_cut_point;
	const int ncp = *input_ncp;
	const int nind = *input_nind;
	const int nind2 = *input_nind2;
	const int ngrp = *input_ngrp;
	const int thr_sample = *input_thr_sample;
	const int thr_grp_sample_size = *input_thr_grp_sample_size;
	const int thr_leaf_size = *input_thr_leaf_size;
	const int nleaf = *input_nleaf;
	const int nperm = *input_nperm;
	const int seed = *input_seed;
	char ** const path_output = input_path_output;
	char ** const path_output_back = input_path_output_back;
	
	bool debug = (*input_debug == 1) ? true : false;
	
	bool trace = (*input_trace == 1) ? true : false;
	
	bool bin = (*input_bin == 1) ? true : false;
	
	
	GENE_CTREE gctree(data, data2, covar, two_way, backward, cal_pval, path_output, 
		path_output_back, N, nind, nind2, ngrp, thr_sample, thr_grp_sample_size,
		thr_leaf_size, nleaf, cut_point, ncp, nperm, trace, seed, debug, bin, pval, pval_back, model);
	gctree.test_tree();
	
}
	
	
}


